"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdditionalInfo = void 0;
var _crash_1 = require("../index");
var ATTRIBUTES = '@attributes';
var AdditionalInfo = (function () {
    function AdditionalInfo(options) {
        this.os = options.os || '';
        this.debuggerOutput = options.debuggerOutput || '';
        this.registers = options.registers || [];
        this.modules = options.modules || [];
        this.threads = options.threads || [];
        Object.freeze(this);
    }
    AdditionalInfo.fromRawResponse = function (response) {
        if (!response) {
            return new AdditionalInfo({
                os: '',
                debuggerOutput: '',
                registers: [],
                modules: [],
                threads: []
            });
        }
        var os = response.os || '';
        var debuggerOutput = !isEmpty(response.process.DebugOutput)
            ? response.process.DebugOutput.DbgEngOutput
            : '';
        var registers = !isEmpty(response.process.exception.registers)
            ? createRegistersArray(response.process.exception.registers)
            : [];
        var threads = !isEmpty(response.process.threads)
            ? createThreadCollectionArray(response.process.threads.thread)
            : [];
        var modules = !isEmpty(response.process.modules)
            ? createModulesArray(response.process.modules.module)
            : [];
        return new AdditionalInfo({
            os: os,
            debuggerOutput: debuggerOutput,
            registers: registers,
            modules: modules,
            threads: threads
        });
    };
    return AdditionalInfo;
}());
exports.AdditionalInfo = AdditionalInfo;
function createModulesArray(modules) {
    if (!modules) {
        modules = [];
    }
    if (!Array.isArray(modules)) {
        modules = [modules];
    }
    return modules.map(function (module) { return _crash_1.Module.fromResponseObject(module); });
}
function createRegistersArray(registers) {
    return _crash_1.Register.fromResponseObject(registers);
}
function createThreadCollectionArray(threads) {
    if (!threads) {
        threads = [];
    }
    if (!Array.isArray(threads)) {
        threads = [threads];
    }
    return threads
        .filter(function (thread) { return thread[ATTRIBUTES].current === 'no' && !isEmpty(thread.frame); })
        .map(function (thread) { return new _crash_1.ThreadCollection({
        threadId: createThreadId(thread),
        stackFrames: createStackFramesArray(thread)
    }); });
}
function createThreadId(thread) {
    return !isEmpty(thread[ATTRIBUTES].id) ? thread[ATTRIBUTES].id : '';
}
function createStackFramesArray(thread) {
    var frames = !isFrameResponseArray(thread.frame)
        ? [thread.frame]
        : thread.frame;
    return frames.map(function (frame) { return new _crash_1.StackFrame({
        fileName: !isEmpty(frame.file) ? frame.file : '',
        functionName: !isEmpty(frame.symbol) ? frame.symbol : '',
        lineNumber: !isEmpty(frame.line) ? parseInt(frame.line) : 0,
        arguments: !isEmpty(frame.arguments) ? frame.arguments : [],
        locals: !isEmpty(frame.locals) ? frame.locals : []
    }); });
}
function isEmpty(obj) {
    if (!obj) {
        return true;
    }
    return Object.keys(obj) && Object.keys(obj).length == 0;
}
function isFrameResponseArray(frame) {
    return Array.isArray(frame);
}
//# sourceMappingURL=additional-info.js.map