"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StackFrame = void 0;
var argument_contracts_1 = __importDefault(require("argument-contracts"));
var splitRegex = /(\\|\/)/;
var StackFrame = (function () {
    function StackFrame(options) {
        var fileName = options.fileName;
        if (fileName) {
            argument_contracts_1.default.assertString(options.fileName, 'options.fileName');
        }
        else {
            fileName = '';
        }
        var functionName = options.functionName;
        if (functionName) {
            argument_contracts_1.default.assertString(options.functionName, 'options.functionName');
        }
        else {
            functionName = '';
        }
        var lineNumber = options.lineNumber;
        if (lineNumber) {
            argument_contracts_1.default.assertNumber(options.lineNumber, 'options.lineNumber');
        }
        else {
            lineNumber = undefined;
        }
        var stackFrameLevel = options.stackFrameLevel;
        if (stackFrameLevel) {
            argument_contracts_1.default.assertNumber(options.stackFrameLevel, 'options.stackFrameLevel');
        }
        else {
            stackFrameLevel = undefined;
        }
        var args = options.arguments || [];
        if (!Array.isArray(args)) {
            args = [args];
        }
        var locals = options.locals || [];
        if (!Array.isArray(locals)) {
            locals = [locals];
        }
        this.fileName = fileName;
        this.functionName = functionName;
        this.lineNumber = lineNumber;
        this.stackFrameLevel = stackFrameLevel;
        this.arguments = args;
        this.locals = locals;
        Object.freeze(this);
    }
    StackFrame.prototype.getDescription = function () {
        if (this.functionName && !this.lineNumber) {
            return "" + this.functionName;
        }
        if (this.functionName && this.lineNumber) {
            return this.functionName + "(" + this.lineNumber + ")";
        }
        return 'Unknown';
    };
    StackFrame.prototype.getLocation = function () {
        if (this.fileName && !this.lineNumber) {
            return "" + this.getShortFileName(this.fileName);
        }
        if (this.fileName && this.lineNumber) {
            return this.getShortFileName(this.fileName) + "(" + this.lineNumber + ")";
        }
        return '';
    };
    StackFrame.prototype.getShortFileName = function (fileName) {
        var _a;
        return (_a = fileName === null || fileName === void 0 ? void 0 : fileName.split(splitRegex).pop()) !== null && _a !== void 0 ? _a : '';
    };
    return StackFrame;
}());
exports.StackFrame = StackFrame;
//# sourceMappingURL=stack-frame.js.map