import { BugSplatApiClient, Environment, S3ApiClient } from '../common/index';
export class CrashPostClient {
    _database;
    _environment;
    _processor;
    _processorApiClient;
    _s3ApiClient;
    constructor(_database, _environment = Environment.Node, _processor = '') {
        this._database = _database;
        this._environment = _environment;
        this._processor = _processor;
        this._processorApiClient = new BugSplatApiClient(`https://${this._database}.bugsplat.com`, this._environment);
        this._s3ApiClient = new S3ApiClient();
    }
    async postCrash(application, version, type, file, md5 = '') {
        const uploadUrl = await this.getCrashUploadUrl(this._database, application, version, file.size);
        await this._s3ApiClient.uploadFileToPresignedUrl(uploadUrl, file);
        return this.commitS3CrashUpload(uploadUrl, this._database, application, version, type, md5, this._processor);
    }
    async getCrashUploadUrl(database, application, version, size) {
        const route = 'api/getCrashUploadUrl'
            + `?database=${database}`
            + `&appName=${application}`
            + `&appVersion=${version}`
            + `&crashPostSize=${size}`;
        const response = await this._processorApiClient.fetch(route);
        if (response.status !== 200) {
            throw new Error('Failed to get crash upload url!');
        }
        const json = await response.json();
        return json.url;
    }
    async commitS3CrashUpload(s3Key, database, application, version, crashType, md5, processor) {
        const route = '/api/commitS3CrashUpload';
        const formData = this._processorApiClient.createFormData();
        formData.append('database', database);
        formData.append('appName', application);
        formData.append('appVersion', version);
        formData.append('crashType', crashType);
        formData.append('s3key', s3Key);
        formData.append('md5', md5);
        if (processor) {
            formData.append('processor', processor);
        }
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            redirect: 'follow'
        };
        return this._processorApiClient.fetch(route, init);
    }
}
//# sourceMappingURL=crash-post-client.js.map